// ****************************************************************************
// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
// This file is part of the hk_classes library.
// This file may be distributed and/or modified under the terms of the
// GNU Library Public License version 2 as published by the Free Software
// Foundation and appearing in the file COPYING included in the
// packaging of this file.
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// ****************************************************************************
#ifndef HK_KDENEWDATABASE_H
#define HK_KDENEWDATABASE_H
#include "hk_kdenewdatabasebase.h"
#include <hk_string.h>


class hk_kdenewdatabase : public hk_kdenewdatabasedialogbase
{
    Q_OBJECT

public:
    hk_kdenewdatabase( const hk_string& drivername,QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~hk_kdenewdatabase();
static hk_string show_dialog(const hk_string& drivername,bool local);

public slots:
    virtual void ok_clicked();
    virtual void directory_clicked();
    virtual void text_changed();
private:
hk_string p_drivername;

};

#endif // HK_KDENEWDATABASE_H
